#ifdef GL_ES
precision mediump float;
#endif

varying vec4 v_color;
varying vec2 v_texCoords;

uniform sampler2D u_texture;

// Adjust this for the number of blur passes
const int numPasses = 5;

// Vignette parameters
const float vignetteIntensity = 1.0;
const float vignetteSmoothness = 0.5;

void main() {
    vec2 texOffset = vec2(1.0 / 1024.0, 1.0 / 1024.0);

    vec4 finalColor = vec4(0.0);

    for (int i = 0; i < numPasses; ++i) {
        float blurOffset = float(numPasses) * 1.05;

        // Apply blur in both directions
        vec4 passColor = vec4(0.0);
        for (float j = -blurOffset; j <= blurOffset; ++j) {
            vec2 offset = vec2(j) * texOffset;
            passColor += texture2D(u_texture, v_texCoords + offset);
        }

        // Normalize by dividing by the total number of samples
        passColor /= (2.0 * blurOffset + 1.0);

        finalColor += passColor;
    }

    // Normalize by dividing by the total number of passes
    finalColor /= float(numPasses);

    // Calculate vignette effect
    vec2 uv = v_texCoords;
    vec2 center = vec2(0.5, 0.5);
    float distance = length(uv - center);
    float vignette = smoothstep(1.0, 1.0 - vignetteIntensity, distance);

    // Apply the vignette effect
    finalColor *= mix(1.0, vignette, vignetteSmoothness);

    gl_FragColor = finalColor * v_color;
}